
#ifndef _C12_kl578_
#define _C12_kl578_

#ifdef __cplusplus
extern "C" {
#endif

static EIF_REFERENCE F636_10631_body(EIF_REFERENCE);
extern EIF_REFERENCE F636_10631(EIF_REFERENCE);
extern void EIF_Minit578(void);

#ifdef __cplusplus
}
#endif

#endif
